@@ -1,6 +1,7 @@
 """Support for the AccuWeather service."""
 from __future__ import annotations
 
+from collections.abc import Callable
 from dataclasses import dataclass
 from typing import Any, cast
 
@@ -13,28 +14,31 @@ from homeassistant.components.sensor import (
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     CONCENTRATION_PARTS_PER_CUBIC_METER,
-    LENGTH_FEET,
-    LENGTH_INCHES,
-    LENGTH_METERS,
-    LENGTH_MILLIMETERS,
     PERCENTAGE,
-    SPEED_KILOMETERS_PER_HOUR,
-    SPEED_MILES_PER_HOUR,
-    TEMP_CELSIUS,
-    TEMP_FAHRENHEIT,
-    TIME_HOURS,
     UV_INDEX,
+    UnitOfLength,
+    UnitOfPrecipitationDepth,
+    UnitOfSpeed,
+    UnitOfTemperature,
+    UnitOfTime,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import StateType
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
+from homeassistant.util.unit_system import METRIC_SYSTEM
 
 from . import AccuWeatherDataUpdateCoordinator
 from .const import (
     API_IMPERIAL,
     API_METRIC,
+    ATTR_CATEGORY,
+    ATTR_DIRECTION,
+    ATTR_ENGLISH,
     ATTR_FORECAST,
+    ATTR_LEVEL,
+    ATTR_SPEED,
+    ATTR_VALUE,
     ATTRIBUTION,
     DOMAIN,
     MAX_FORECAST_DAYS,
@@ -44,11 +48,21 @@ PARALLEL_UPDATES = 1
 
 
 @dataclass
-class AccuWeatherSensorDescription(SensorEntityDescription):
+class AccuWeatherSensorDescriptionMixin:
+    """Mixin for AccuWeather sensor."""
+
+    value_fn: Callable[[dict[str, Any], str], StateType]
+
+
+@dataclass
+class AccuWeatherSensorDescription(
+    SensorEntityDescription, AccuWeatherSensorDescriptionMixin
+):
     """Class describing AccuWeather sensor entities."""
 
-    unit_metric: str | None = None
-    unit_imperial: str | None = None
+    attr_fn: Callable[[dict[str, Any]], dict[str, StateType]] = lambda _: {}
+    metric_unit: str | None = None
+    us_customary_unit: str | None = None
 
 
 FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
@@ -56,145 +70,162 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         key="CloudCoverDay",
         icon="mdi:weather-cloudy",
         name="Cloud cover day",
-        unit_metric=PERCENTAGE,
-        unit_imperial=PERCENTAGE,
         entity_registry_enabled_default=False,
+        native_unit_of_measurement=PERCENTAGE,
+        value_fn=lambda data, _: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="CloudCoverNight",
         icon="mdi:weather-cloudy",
         name="Cloud cover night",
-        unit_metric=PERCENTAGE,
-        unit_imperial=PERCENTAGE,
         entity_registry_enabled_default=False,
+        native_unit_of_measurement=PERCENTAGE,
+        value_fn=lambda data, _: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="Grass",
         icon="mdi:grass",
         name="Grass pollen",
-        unit_metric=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        unit_imperial=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="HoursOfSun",
         icon="mdi:weather-partly-cloudy",
         name="Hours of sun",
-        unit_metric=TIME_HOURS,
-        unit_imperial=TIME_HOURS,
+        native_unit_of_measurement=UnitOfTime.HOURS,
+        value_fn=lambda data, _: cast(float, data),
     ),
     AccuWeatherSensorDescription(
         key="Mold",
         icon="mdi:blur",
         name="Mold pollen",
-        unit_metric=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        unit_imperial=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="Ozone",
         icon="mdi:vector-triangle",
         name="Ozone",
-        unit_metric=None,
-        unit_imperial=None,
         entity_registry_enabled_default=False,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="Ragweed",
         icon="mdi:sprout",
         name="Ragweed pollen",
-        unit_metric=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        unit_imperial=CONCENTRATION_PARTS_PER_CUBIC_METER,
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureMax",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature max",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureMin",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature min",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShadeMax",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature shade max",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShadeMin",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature shade min",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="ThunderstormProbabilityDay",
         icon="mdi:weather-lightning",
         name="Thunderstorm probability day",
-        unit_metric=PERCENTAGE,
-        unit_imperial=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
+        value_fn=lambda data, _: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="ThunderstormProbabilityNight",
         icon="mdi:weather-lightning",
         name="Thunderstorm probability night",
-        unit_metric=PERCENTAGE,
-        unit_imperial=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
+        value_fn=lambda data, _: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="Tree",
         icon="mdi:tree-outline",
         name="Tree pollen",
-        unit_metric=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        unit_imperial=CONCENTRATION_PARTS_PER_CUBIC_METER,
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="UVIndex",
         icon="mdi:weather-sunny",
         name="UV index",
-        unit_metric=UV_INDEX,
-        unit_imperial=UV_INDEX,
+        native_unit_of_measurement=UV_INDEX,
+        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
     ),
     AccuWeatherSensorDescription(
         key="WindGustDay",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind gust day",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
         entity_registry_enabled_default=False,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
         key="WindGustNight",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind gust night",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
         entity_registry_enabled_default=False,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
         key="WindDay",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind day",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
         key="WindNight",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind night",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
 )
 
@@ -203,112 +234,124 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         key="ApparentTemperature",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="Apparent temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Ceiling",
+        device_class=SensorDeviceClass.DISTANCE,
         icon="mdi:weather-fog",
         name="Cloud ceiling",
-        unit_metric=LENGTH_METERS,
-        unit_imperial=LENGTH_FEET,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfLength.METERS,
+        us_customary_unit=UnitOfLength.FEET,
+        value_fn=lambda data, unit: round(cast(float, data[unit][ATTR_VALUE])),
     ),
     AccuWeatherSensorDescription(
         key="CloudCover",
         icon="mdi:weather-cloudy",
         name="Cloud cover",
-        unit_metric=PERCENTAGE,
-        unit_imperial=PERCENTAGE,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        native_unit_of_measurement=PERCENTAGE,
+        value_fn=lambda data, _: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="DewPoint",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="Dew point",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperature",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShade",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature shade",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Precipitation",
-        icon="mdi:weather-rainy",
+        device_class=SensorDeviceClass.PRECIPITATION,
         name="Precipitation",
-        unit_metric=LENGTH_MILLIMETERS,
-        unit_imperial=LENGTH_INCHES,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfPrecipitationDepth.MILLIMETERS,
+        us_customary_unit=UnitOfPrecipitationDepth.INCHES,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        attr_fn=lambda data: {"type": data["PrecipitationType"]},
     ),
     AccuWeatherSensorDescription(
         key="PressureTendency",
-        device_class="accuweather__pressure_tendency",
         icon="mdi:gauge",
         name="Pressure tendency",
-        unit_metric=None,
-        unit_imperial=None,
+        translation_key="pressure_tendency",
+        value_fn=lambda data, _: cast(str, data["LocalizedText"]).lower(),
     ),
     AccuWeatherSensorDescription(
         key="UVIndex",
         icon="mdi:weather-sunny",
         name="UV index",
-        unit_metric=UV_INDEX,
-        unit_imperial=UV_INDEX,
         state_class=SensorStateClass.MEASUREMENT,
+        native_unit_of_measurement=UV_INDEX,
+        value_fn=lambda data, _: cast(int, data),
+        attr_fn=lambda data: {ATTR_LEVEL: data["UVIndexText"]},
     ),
     AccuWeatherSensorDescription(
         key="WetBulbTemperature",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="Wet bulb temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="WindChillTemperature",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="Wind chill temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfTemperature.CELSIUS,
+        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
+        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Wind",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, unit: cast(float, data[ATTR_SPEED][unit][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="WindGust",
-        icon="mdi:weather-windy",
+        device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind gust",
-        unit_metric=SPEED_KILOMETERS_PER_HOUR,
-        unit_imperial=SPEED_MILES_PER_HOUR,
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
+        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
+        value_fn=lambda data, unit: cast(float, data[ATTR_SPEED][unit][ATTR_VALUE]),
     ),
 )
 
@@ -320,19 +363,19 @@ async def async_setup_entry(
 
     coordinator: AccuWeatherDataUpdateCoordinator = hass.data[DOMAIN][entry.entry_id]
 
-    sensors: list[AccuWeatherSensor] = []
-    for description in SENSOR_TYPES:
-        sensors.append(AccuWeatherSensor(coordinator, description))
+    sensors = [
+        AccuWeatherSensor(coordinator, description) for description in SENSOR_TYPES
+    ]
 
     if coordinator.forecast:
-        for description in FORECAST_SENSOR_TYPES:
-            for day in range(MAX_FORECAST_DAYS + 1):
-                # Some air quality/allergy sensors are only available for certain
-                # locations.
-                if description.key in coordinator.data[ATTR_FORECAST][0]:
-                    sensors.append(
-                        AccuWeatherSensor(coordinator, description, forecast_day=day)
-                    )
+        # Some air quality/allergy sensors are only available for certain
+        # locations.
+        sensors.extend(
+            AccuWeatherForecastSensor(coordinator, description, forecast_day=day)
+            for day in range(MAX_FORECAST_DAYS + 1)
+            for description in FORECAST_SENSOR_TYPES
+            if description.key in coordinator.data[ATTR_FORECAST][0]
+        )
 
     async_add_entities(sensors)
 
@@ -356,9 +399,8 @@ class AccuWeatherSensor(
         super().__init__(coordinator)
         self.entity_description = description
         self._sensor_data = _get_sensor_data(
-            coordinator.data, forecast_day, description.key
+            coordinator.data, description.key, forecast_day
         )
-        self._attrs: dict[str, Any] = {}
         if forecast_day is not None:
             self._attr_name = f"{description.name} {forecast_day}d"
             self._attr_unique_id = (
@@ -368,82 +410,42 @@ class AccuWeatherSensor(
             self._attr_unique_id = (
                 f"{coordinator.location_key}-{description.key}".lower()
             )
-        if coordinator.is_metric:
+        self._attr_native_unit_of_measurement = description.native_unit_of_measurement
+        if self.coordinator.hass.config.units is METRIC_SYSTEM:
             self._unit_system = API_METRIC
-            self._attr_native_unit_of_measurement = description.unit_metric
+            if metric_unit := description.metric_unit:
+                self._attr_native_unit_of_measurement = metric_unit
         else:
             self._unit_system = API_IMPERIAL
-            self._attr_native_unit_of_measurement = description.unit_imperial
+            if us_customary_unit := description.us_customary_unit:
+                self._attr_native_unit_of_measurement = us_customary_unit
         self._attr_device_info = coordinator.device_info
-        self.forecast_day = forecast_day
+        if forecast_day is not None:
+            self.forecast_day = forecast_day
 
     @property
     def native_value(self) -> StateType:
         """Return the state."""
-        if self.forecast_day is not None:
-            if self.entity_description.device_class == SensorDeviceClass.TEMPERATURE:
-                return cast(float, self._sensor_data["Value"])
-            if self.entity_description.key == "UVIndex":
-                return cast(int, self._sensor_data["Value"])
-        if self.entity_description.key in ("Grass", "Mold", "Ragweed", "Tree", "Ozone"):
-            return cast(int, self._sensor_data["Value"])
-        if self.entity_description.key == "Ceiling":
-            return round(self._sensor_data[self._unit_system]["Value"])
-        if self.entity_description.key == "PressureTendency":
-            return cast(str, self._sensor_data["LocalizedText"].lower())
-        if self.entity_description.device_class == SensorDeviceClass.TEMPERATURE:
-            return cast(float, self._sensor_data[self._unit_system]["Value"])
-        if self.entity_description.key == "Precipitation":
-            return cast(float, self._sensor_data[self._unit_system]["Value"])
-        if self.entity_description.key in ("Wind", "WindGust"):
-            return cast(float, self._sensor_data["Speed"][self._unit_system]["Value"])
-        if self.entity_description.key in (
-            "WindDay",
-            "WindNight",
-            "WindGustDay",
-            "WindGustNight",
-        ):
-            return cast(StateType, self._sensor_data["Speed"]["Value"])
-        return cast(StateType, self._sensor_data)
+        return self.entity_description.value_fn(self._sensor_data, self._unit_system)
 
     @property
     def extra_state_attributes(self) -> dict[str, Any]:
         """Return the state attributes."""
-        if self.forecast_day is not None:
-            if self.entity_description.key in (
-                "WindDay",
-                "WindNight",
-                "WindGustDay",
-                "WindGustNight",
-            ):
-                self._attrs["direction"] = self._sensor_data["Direction"]["English"]
-            elif self.entity_description.key in (
-                "Grass",
-                "Mold",
-                "Ozone",
-                "Ragweed",
-                "Tree",
-                "UVIndex",
-            ):
-                self._attrs["level"] = self._sensor_data["Category"]
-            return self._attrs
-        if self.entity_description.key == "UVIndex":
-            self._attrs["level"] = self.coordinator.data["UVIndexText"]
-        elif self.entity_description.key == "Precipitation":
-            self._attrs["type"] = self.coordinator.data["PrecipitationType"]
-        return self._attrs
+        return self.entity_description.attr_fn(self.coordinator.data)
 
     @callback
     def _handle_coordinator_update(self) -> None:
         """Handle data update."""
         self._sensor_data = _get_sensor_data(
-            self.coordinator.data, self.forecast_day, self.entity_description.key
+            self.coordinator.data, self.entity_description.key
         )
         self.async_write_ha_state()
 
 
 def _get_sensor_data(
-    sensors: dict[str, Any], forecast_day: int | None, kind: str
+    sensors: dict[str, Any],
+    kind: str,
+    forecast_day: int | None = None,
 ) -> Any:
     """Get sensor data."""
     if forecast_day is not None:
@@ -453,3 +455,20 @@ def _get_sensor_data(
         return sensors["PrecipitationSummary"][kind]
 
     return sensors[kind]
+
+
+class AccuWeatherForecastSensor(AccuWeatherSensor):
+    """Define an AccuWeather forecast entity."""
+
+    @property
+    def extra_state_attributes(self) -> dict[str, Any]:
+        """Return the state attributes."""
+        return self.entity_description.attr_fn(self._sensor_data)
+
+    @callback
+    def _handle_coordinator_update(self) -> None:
+        """Handle data update."""
+        self._sensor_data = _get_sensor_data(
+            self.coordinator.data, self.entity_description.key, self.forecast_day
+        )
+        self.async_write_ha_state()
