@@ -94,14 +94,9 @@ class BMWConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         return BMWOptionsFlow(config_entry)
 
 
-class BMWOptionsFlow(config_entries.OptionsFlow):
+class BMWOptionsFlow(config_entries.OptionsFlowWithConfigEntry):
     """Handle a option flow for MyBMW."""
 
-    def __init__(self, config_entry: config_entries.ConfigEntry) -> None:
-        """Initialize MyBMW option flow."""
-        self.config_entry = config_entry
-        self.options = dict(config_entry.options)
-
     async def async_step_init(
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
