@@ -128,6 +128,18 @@ HUE_TAP_REMOTE = {
     (CONF_SHORT_PRESS, CONF_BUTTON_4): {CONF_EVENT: 18},
 }
 
+HUE_WALL_REMOTE_MODEL = "RDM001"  # Hue wall switch
+HUE_WALL_REMOTE = {
+    (CONF_SHORT_PRESS, CONF_BUTTON_1): {CONF_EVENT: 1000},
+    (CONF_SHORT_RELEASE, CONF_BUTTON_1): {CONF_EVENT: 1002},
+    (CONF_LONG_PRESS, CONF_BUTTON_1): {CONF_EVENT: 1001},
+    (CONF_LONG_RELEASE, CONF_BUTTON_1): {CONF_EVENT: 1003},
+    (CONF_SHORT_PRESS, CONF_BUTTON_2): {CONF_EVENT: 2000},
+    (CONF_SHORT_RELEASE, CONF_BUTTON_2): {CONF_EVENT: 2002},
+    (CONF_LONG_PRESS, CONF_BUTTON_2): {CONF_EVENT: 2001},
+    (CONF_LONG_RELEASE, CONF_BUTTON_2): {CONF_EVENT: 2003},
+}
+
 FRIENDS_OF_HUE_SWITCH_MODEL = "FOHSWITCH"
 FRIENDS_OF_HUE_SWITCH = {
     (CONF_SHORT_PRESS, CONF_BUTTON_1): {CONF_EVENT: 1000},
@@ -158,18 +170,18 @@ FRIENDS_OF_HUE_SWITCH = {
 
 STYRBAR_REMOTE_MODEL = "Remote Control N2"
 STYRBAR_REMOTE = {
-    (CONF_SHORT_RELEASE, CONF_TURN_ON): {CONF_EVENT: 1002},
-    (CONF_LONG_PRESS, CONF_TURN_ON): {CONF_EVENT: 1001},
-    (CONF_LONG_RELEASE, CONF_TURN_ON): {CONF_EVENT: 1003},
-    (CONF_SHORT_RELEASE, CONF_DIM_UP): {CONF_EVENT: 2002},
-    (CONF_LONG_PRESS, CONF_DIM_UP): {CONF_EVENT: 2001},
-    (CONF_LONG_RELEASE, CONF_DIM_UP): {CONF_EVENT: 2003},
-    (CONF_SHORT_RELEASE, CONF_DIM_DOWN): {CONF_EVENT: 3002},
-    (CONF_LONG_PRESS, CONF_DIM_DOWN): {CONF_EVENT: 3001},
-    (CONF_LONG_RELEASE, CONF_DIM_DOWN): {CONF_EVENT: 3003},
-    (CONF_SHORT_RELEASE, CONF_TURN_OFF): {CONF_EVENT: 4002},
-    (CONF_LONG_PRESS, CONF_TURN_OFF): {CONF_EVENT: 4001},
-    (CONF_LONG_RELEASE, CONF_TURN_OFF): {CONF_EVENT: 4003},
+    (CONF_SHORT_RELEASE, CONF_DIM_UP): {CONF_EVENT: 1002},
+    (CONF_LONG_PRESS, CONF_DIM_UP): {CONF_EVENT: 1001},
+    (CONF_LONG_RELEASE, CONF_DIM_UP): {CONF_EVENT: 1003},
+    (CONF_SHORT_RELEASE, CONF_DIM_DOWN): {CONF_EVENT: 2002},
+    (CONF_LONG_PRESS, CONF_DIM_DOWN): {CONF_EVENT: 2001},
+    (CONF_LONG_RELEASE, CONF_DIM_DOWN): {CONF_EVENT: 2003},
+    (CONF_SHORT_RELEASE, CONF_LEFT): {CONF_EVENT: 3002},
+    (CONF_LONG_PRESS, CONF_LEFT): {CONF_EVENT: 3001},
+    (CONF_LONG_RELEASE, CONF_LEFT): {CONF_EVENT: 3003},
+    (CONF_SHORT_RELEASE, CONF_RIGHT): {CONF_EVENT: 4002},
+    (CONF_LONG_PRESS, CONF_RIGHT): {CONF_EVENT: 4001},
+    (CONF_LONG_RELEASE, CONF_RIGHT): {CONF_EVENT: 4003},
 }
 
 SYMFONISK_SOUND_CONTROLLER_MODEL = "SYMFONISK Sound Controller"
@@ -582,6 +594,7 @@ REMOTES = {
     HUE_DIMMER_REMOTE_MODEL_GEN3: HUE_DIMMER_REMOTE,
     HUE_BUTTON_REMOTE_MODEL: HUE_BUTTON_REMOTE,
     HUE_TAP_REMOTE_MODEL: HUE_TAP_REMOTE,
+    HUE_WALL_REMOTE_MODEL: HUE_WALL_REMOTE,
     FRIENDS_OF_HUE_SWITCH_MODEL: FRIENDS_OF_HUE_SWITCH,
     STYRBAR_REMOTE_MODEL: STYRBAR_REMOTE,
     SYMFONISK_SOUND_CONTROLLER_MODEL: SYMFONISK_SOUND_CONTROLLER,
