@@ -1,6 +1,7 @@
 """Config flow for Forecast.Solar integration."""
 from __future__ import annotations
 
+import re
 from typing import Any
 
 import voluptuous as vol
@@ -9,7 +10,7 @@ from homeassistant.config_entries import ConfigEntry, ConfigFlow, OptionsFlow
 from homeassistant.const import CONF_API_KEY, CONF_LATITUDE, CONF_LONGITUDE, CONF_NAME
 from homeassistant.core import callback
 from homeassistant.data_entry_flow import FlowResult
-import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers import config_validation as cv
 
 from .const import (
     CONF_AZIMUTH,
@@ -20,6 +21,8 @@ from .const import (
     DOMAIN,
 )
 
+RE_API_KEY = re.compile(r"^[a-zA-Z0-9]{16}$")
+
 
 class ForecastSolarFlowHandler(ConfigFlow, domain=DOMAIN):
     """Handle a config flow for Forecast.Solar."""
@@ -88,8 +91,16 @@ class ForecastSolarOptionFlowHandler(OptionsFlow):
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
         """Manage the options."""
+        errors = {}
         if user_input is not None:
-            return self.async_create_entry(title="", data=user_input)
+            if (api_key := user_input.get(CONF_API_KEY)) and RE_API_KEY.match(
+                api_key
+            ) is None:
+                errors[CONF_API_KEY] = "invalid_api_key"
+            else:
+                return self.async_create_entry(
+                    title="", data=user_input | {CONF_API_KEY: api_key or None}
+                )
 
         return self.async_show_form(
             step_id="init",
@@ -129,4 +140,5 @@ class ForecastSolarOptionFlowHandler(OptionsFlow):
                     ): vol.Coerce(int),
                 }
             ),
+            errors=errors,
         )
