@@ -11,7 +11,7 @@ from typing import Any, Generic, TypeVar
 from nibe.coil import Coil
 from nibe.connection import Connection
 from nibe.connection.modbus import Modbus
-from nibe.connection.nibegw import NibeGW
+from nibe.connection.nibegw import NibeGW, ProductInfo
 from nibe.exceptions import CoilNotFoundException, CoilReadException
 from nibe.heatpump import HeatPump, Model, Series
 
@@ -48,6 +48,8 @@ from .const import (
 
 PLATFORMS: list[Platform] = [
     Platform.BINARY_SENSOR,
+    Platform.BUTTON,
+    Platform.CLIMATE,
     Platform.NUMBER,
     Platform.SELECT,
     Platform.SENSOR,
@@ -98,14 +100,25 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     data[entry.entry_id] = coordinator
 
     reg = dr.async_get(hass)
-    reg.async_get_or_create(
+    device_entry = reg.async_get_or_create(
         config_entry_id=entry.entry_id,
         identifiers={(DOMAIN, entry.unique_id or entry.entry_id)},
         manufacturer="NIBE Energy Systems",
-        model=heatpump.model.name,
         name=heatpump.model.name,
     )
 
+    def _on_product_info(product_info: ProductInfo):
+        reg.async_update_device(
+            device_id=device_entry.id,
+            model=product_info.model,
+            sw_version=str(product_info.firmware_version),
+        )
+
+    if isinstance(connection, NibeGW):
+        connection.subscribe(connection.PRODUCT_INFO_EVENT, _on_product_info)
+    else:
+        reg.async_update_device(device_id=device_entry.id, model=heatpump.model.name)
+
     await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
     # Trigger a refresh again now that all platforms have registered
@@ -156,6 +169,8 @@ class ContextCoordinator(
         self, update_callback: CALLBACK_TYPE, context: Any = None
     ) -> Callable[[], None]:
         """Wrap standard function to prune cached callback database."""
+        assert isinstance(context, set)
+        context -= {None}
         release = super().async_add_listener(update_callback, context)
         self.__dict__.pop("context_callbacks", None)
 
@@ -238,6 +253,10 @@ class Coordinator(ContextCoordinator[dict[int, Coil], int]):
 
         self.async_update_context_listeners([coil.address])
 
+    async def async_read_coil(self, coil: Coil) -> Coil:
+        """Read coil and update state using callbacks."""
+        return await self.connection.read_coil(coil)
+
     async def _async_update_data(self) -> dict[int, Coil]:
         self.task = asyncio.current_task()
         try:
@@ -268,7 +287,11 @@ class Coordinator(ContextCoordinator[dict[int, Coil], int]):
                 result[coil.address] = coil
                 self.seed.pop(coil.address, None)
         except CoilReadException as exception:
-            raise UpdateFailed(f"Failed to update: {exception}") from exception
+            if not result:
+                raise UpdateFailed(f"Failed to update: {exception}") from exception
+            self.logger.debug(
+                "Some coils failed to update, and may be unsupported: %s", exception
+            )
 
         return result
 
