@@ -1,13 +1,11 @@
 """Parent class for every Overkiz device."""
 from __future__ import annotations
 
-from enum import unique
 from typing import cast
 
 from pyoverkiz.enums import OverkizAttribute, OverkizState
 from pyoverkiz.models import Device
 
-from homeassistant.backports.enum import StrEnum
 from homeassistant.helpers.entity import DeviceInfo, EntityDescription
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
@@ -118,18 +116,3 @@ class OverkizDescriptiveEntity(OverkizEntity):
         if self.is_sub_device:
             # In case of sub device, use the provided label and append the name of the type of entity
             self._attr_name = f"{self.device.label} {description.name}"
-
-
-# Used by state translations for sensor and select entities
-@unique
-class OverkizDeviceClass(StrEnum):
-    """Device class for Overkiz specific devices."""
-
-    BATTERY = "overkiz__battery"
-    DISCRETE_RSSI_LEVEL = "overkiz__discrete_rssi_level"
-    MEMORIZED_SIMPLE_VOLUME = "overkiz__memorized_simple_volume"
-    OPEN_CLOSED_PEDESTRIAN = "overkiz__open_closed_pedestrian"
-    PRIORITY_LOCK_ORIGINATOR = "overkiz__priority_lock_originator"
-    SENSOR_DEFECT = "overkiz__sensor_defect"
-    SENSOR_ROOM = "overkiz__sensor_room"
-    THREE_WAY_HANDLE_DIRECTION = "overkiz__three_way_handle_direction"
