@@ -47,10 +47,12 @@ async def async_setup_platform(
 ) -> None:
     """Set up the ZAMG weather platform."""
     # trigger import flow
-    await hass.config_entries.flow.async_init(
-        DOMAIN,
-        context={"source": SOURCE_IMPORT},
-        data=config,
+    hass.async_create_task(
+        hass.config_entries.flow.async_init(
+            DOMAIN,
+            context={"source": SOURCE_IMPORT},
+            data=config,
+        )
     )
 
 
@@ -67,12 +69,14 @@ async def async_setup_entry(
 class ZamgWeather(CoordinatorEntity, WeatherEntity):
     """Representation of a weather condition."""
 
+    _attr_attribution = ATTRIBUTION
+
     def __init__(
-        self, coordinator: ZamgDataUpdateCoordinator, name, station_id
+        self, coordinator: ZamgDataUpdateCoordinator, name: str, station_id: str
     ) -> None:
         """Initialise the platform with a data instance and station name."""
         super().__init__(coordinator)
-        self._attr_unique_id = f"{name}_{station_id}"
+        self._attr_unique_id = station_id
         self._attr_name = f"ZAMG {name}"
         self.station_id = f"{station_id}"
         self._attr_device_info = DeviceInfo(
@@ -93,47 +97,42 @@ class ZamgWeather(CoordinatorEntity, WeatherEntity):
         """Return the current condition."""
         return None
 
-    @property
-    def attribution(self) -> str | None:
-        """Return the attribution."""
-        return ATTRIBUTION
-
     @property
     def native_temperature(self) -> float | None:
         """Return the platform temperature."""
         try:
-            return float(self.coordinator.data[self.station_id].get("TL")["data"])
-        except (TypeError, ValueError):
+            return float(self.coordinator.data[self.station_id]["TL"]["data"])
+        except (KeyError, ValueError):
             return None
 
     @property
     def native_pressure(self) -> float | None:
         """Return the pressure."""
         try:
-            return float(self.coordinator.data[self.station_id].get("P")["data"])
-        except (TypeError, ValueError):
+            return float(self.coordinator.data[self.station_id]["P"]["data"])
+        except (KeyError, ValueError):
             return None
 
     @property
     def humidity(self) -> float | None:
         """Return the humidity."""
         try:
-            return float(self.coordinator.data[self.station_id].get("RFAM")["data"])
-        except (TypeError, ValueError):
+            return float(self.coordinator.data[self.station_id]["RFAM"]["data"])
+        except (KeyError, ValueError):
             return None
 
     @property
     def native_wind_speed(self) -> float | None:
         """Return the wind speed."""
         try:
-            return float(self.coordinator.data[self.station_id].get("FF")["data"])
-        except (TypeError, ValueError):
+            return float(self.coordinator.data[self.station_id]["FFAM"]["data"])
+        except (KeyError, ValueError):
             return None
 
     @property
     def wind_bearing(self) -> float | str | None:
         """Return the wind bearing."""
         try:
-            return self.coordinator.data[self.station_id].get("DD")["data"]
-        except (TypeError, ValueError):
+            return self.coordinator.data[self.station_id]["DD"]["data"]
+        except (KeyError, ValueError):
             return None
